@@ -9,6 +9,7 @@ pub struct Ndk {
     sdk_path: PathBuf,
     ndk_path: PathBuf,
     build_tools_version: String,
+    build_tag: u32,
     platforms: Vec<u32>,
 }
 
@@ -54,6 +55,31 @@ impl Ndk {
             .max()
             .ok_or(NdkError::BuildToolsNotFound)?;
 
+        let build_tag = std::fs::read_to_string(ndk_path.join("source.properties"))
+            .expect("Failed to read source.properties");
+
+        let build_tag = build_tag
+            .split('\n')
+            .find_map(|line| {
+                let (key, value) = line
+                    .split_once('=')
+                    .expect("Failed to parse `key = value` from source.properties");
+                if key.trim() == "Pkg.Revision" {
+                    // AOSP writes a constantly-incrementing build version to the patch field.
+                    // This number is incrementing across NDK releases.
+                    let mut parts = value.trim().split('.');
+                    let _major = parts.next().unwrap();
+                    let _minor = parts.next().unwrap();
+                    let patch = parts.next().unwrap();
+                    // Can have an optional `XXX-beta1`
+                    let patch = patch.split_once('-').map_or(patch, |(patch, _beta)| patch);
+                    Some(patch.parse().expect("Failed to parse patch field"))
+                } else {
+                    None
+                }
+            })
+            .expect("No `Pkg.Revision` in source.properties");
+
         let ndk_platforms = std::fs::read_to_string(ndk_path.join("build/core/platforms.mk"))?;
         let ndk_platforms = ndk_platforms
             .split('\n')
@@ -88,6 +114,7 @@ impl Ndk {
             sdk_path,
             ndk_path,
             build_tools_version,
+            build_tag,
             platforms,
         })
     }
@@ -104,6 +131,10 @@ impl Ndk {
         &self.build_tools_version
     }
 
+    pub fn build_tag(&self) -> u32 {
+        self.build_tag
+    }
+
     pub fn platforms(&self) -> &[u32] {
         &self.platforms
     }
@@ -128,10 +159,18 @@ impl Ndk {
         Ok(Command::new(dunce::canonicalize(path)?))
     }
 
-    pub fn default_platform(&self) -> u32 {
+    pub fn highest_supported_platform(&self) -> u32 {
         self.platforms().iter().max().cloned().unwrap()
     }
 
+    /// Returns platform `30` as currently [required by Google Play], or lower
+    /// when the detected SDK does not support it yet.
+    ///
+    /// [required by Google Play]: https://developer.android.com/distribute/best-practices/develop/target-sdk
+    pub fn default_target_platform(&self) -> u32 {
+        self.highest_supported_platform().min(30)
+    }
+
     pub fn platform_dir(&self, platform: u32) -> Result<PathBuf, NdkError> {
         let dir = self
             .sdk_path
@@ -234,7 +273,7 @@ impl Ndk {
             llvm_path
                 .exists()
                 .then(|| llvm_path)
-                .ok_or_else(|| NdkError::ToolchainBinaryNotFound {
+                .ok_or(NdkError::ToolchainBinaryNotFound {
                     toolchain_path,
                     gnu_bin,
                     llvm_bin,
